@@ -393,6 +393,11 @@ class EssbasicClient(AbstractClient):
         - B端企业的签署方式是静默签署
         - B端企业是非首位签署
 
+        通过一码多扫二维码发起的合同，合同涉及到的回调消息可参考文档[合同发起及签署相关回调
+        ]( https://qian.tencent.com/developers/partner/callback_types_contracts_sign)
+
+        用户通过签署二维码发起合同时，因企业额度不足导致失败 会触发签署二维码相关回调,具体参考文档[签署二维码相关回调](https://qian.tencent.com/developers/partner/callback_types_commons#%E7%AD%BE%E7%BD%B2%E4%BA%8C%E7%BB%B4%E7%A0%81%E7%9B%B8%E5%85%B3%E5%9B%9E%E8%B0%83)
+
         :param request: Request instance for ChannelCreateMultiFlowSignQRCode.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateMultiFlowSignQRCodeRequest`
         :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateMultiFlowSignQRCodeResponse`
@@ -986,6 +991,13 @@ class EssbasicClient(AbstractClient):
         其中小程序的原始Id，请联系<对接技术人员>获取，或者查看小程序信息自助获取。
         使用CreateSignUrls，设置EndPoint为APP，得到path。
 
+        其中小程序的原始Id如下，或者查看小程序信息自助获取。
+
+        | 小程序 | AppID | 原始ID |
+        | ------------ | ------------ | ------------ |
+        | 腾讯电子签（正式版） | wxa023b292fd19d41d | gh_da88f6188665 |
+        | 腾讯电子签Demo | wx371151823f6f3edf | gh_39a5d3de69fa |
+
         :param request: Request instance for CreateSignUrls.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSignUrlsRequest`
         :rtype: :class:`tencentcloud.essbasic.v20210526.models.CreateSignUrlsResponse`
